@@ -29,7 +29,7 @@ import logging
 from Iuppiter.Util import extendUnique
 from Iuppiter.DjangoUtil import extendInstalledApps
 
-from Version import ZEPHYRUS_VERSION
+from .Version import ZEPHYRUS_VERSION
 
 def createLogger(name, fileHandlerName):
     logger = logging.getLogger(name)
@@ -94,8 +94,8 @@ def attachSettings(settingsDict):
         'Zephyrus.landing',
         'Zephyrus.facebook',
         'Zephyrus.line',
-        'drip',
-        'Zephyrus.autoresponder',
+        #'drip',
+        #'Zephyrus.autoresponder',
         'robots',
     ]
 
@@ -111,7 +111,8 @@ def attachSettings(settingsDict):
             'sortedm2m',
             'taggit',
             'haystack',
-
+            
+            'django.contrib.redirects',
             'Zephyrus.blog_extension',
             'Zephyrus.comment',
             'django_gravatar',
