@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10864 2018-03-18 08:28:24Z Lavender $
+# $Id: __init__.py 11376 2019-03-03 14:21:00Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,12 +12,13 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-03-18 16:28:24 +0800 (週日, 18 三月 2018) $
-# $Revision: 10864 $
+# $Date: 2019-03-03 23:21:00 +0900 (週日, 03 三月 2019) $
+# $Revision: 11376 $
 
 import os
 import logging
 import platform
+import six
 
 from django.conf import settings
 
@@ -79,6 +80,15 @@ def createLogger(name, fileHandlerName):
     fileHandler.setLevel(logging.WARNING)
     logger.addHandler(fileHandler)
     return logger
+    
+def toBytes(s):
+    return s if six.PY2 else s.encode()
+    
+def open3(name, mode='r'):
+    if six.PY2:
+        return open(name, mode)
+    else:
+        return open(name, mode, encoding='utf8')
 
 CSS_PROPERTIES = [
     #CSS3: https://www.w3schools.com/cssref/default.asp
