@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_boilerplate2.py 11055 2018-05-14 09:46:32Z Lavender $
+# $Id: build_boilerplate2.py 11376 2019-03-03 14:21:00Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,14 +12,16 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
-# $Revision: 11055 $
+# $Date: 2019-03-03 23:21:00 +0900 (週日, 03 三月 2019) $
+# $Revision: 11376 $
 
 import os
 import re
 import hashlib
 import json
 import traceback
+import six
+import collections
 
 import cms
 
@@ -29,26 +31,11 @@ from lxml.html.soupparser import parse
 from django.core.management.base import BaseCommand
 from django.conf import settings
 from django.template.loader import get_template
-from BeautifulSoup import (
-        BeautifulSoup, Tag, Comment, ProcessingInstruction, NavigableString,
-        Declaration, CData)
-_DECLARATION_OR_DOCTYPE = Declaration
-
-# 因為 lxml 關於使用哪個 BeautifulSoup 來 parse 的機制沒有設計得很完善會有 bug
-# 因此使用 monkey patch 來做
-# 注意: 別 Import 此檔案
-soupparser.BeautifulSoup = BeautifulSoup
-soupparser.Tag = Tag
-soupparser.Comment = Comment
-soupparser.ProcessingInstruction = ProcessingInstruction
-soupparser.NavigableString = NavigableString
-soupparser.Declaration = Declaration
-soupparser.CData = CData
-soupparser._DECLARATION_OR_DOCTYPE = _DECLARATION_OR_DOCTYPE
 
 from Zephyrus.boilerplate.management.commands import (
     TEMPLATES_DIR_PATH, STATIC_DIR_PATH, ROOT_DIR_PATH)
-from Zephyrus.boilerplate.management.commands import createLogger
+from Zephyrus.boilerplate.management.commands import createLogger, toBytes
+from Zephyrus.boilerplate.management.commands import open3 as open
 
 logger = createLogger(__name__, "BuildBoilerplate2.log")
 
@@ -142,9 +129,9 @@ class Command(BaseCommand):
             # static and html file md5 dict ----------------------------------------
             staticDict = self.buildFileDict('static')
             staticDict['js/FixTemplate.js'] = \
-                hashlib.md5('js/FixTemplate.js').hexdigest()
+                hashlib.md5(toBytes('js/FixTemplate.js')).hexdigest()
             staticDict['js/CMSContext.js'] = \
-                hashlib.md5('js/CMSContext.js').hexdigest()
+                hashlib.md5(toBytes('js/CMSContext.js')).hexdigest()
             templateDict = self.buildFileDict('templates')
             fileDict = dict(staticDict)
             fileDict.update(templateDict)
@@ -165,7 +152,7 @@ class Command(BaseCommand):
                             continue
 
                         # etree ------------------------------------------------
-                        page = parse(f, beautifulsoup=BeautifulSoup)
+                        page = parse(f)
                         
                         # replace word
                         self.changeWordToMd5(page)
@@ -273,13 +260,15 @@ class Command(BaseCommand):
                 for f in files:
                     index = len(STATIC_DIR_PATH) + 1
                     filePath = os.path.join(root, f)[index:].replace('\\', '/')
-                    fileDict[filePath] = hashlib.md5(filePath).hexdigest()
+                    fileDict[filePath] = hashlib.md5(
+                        toBytes(filePath)).hexdigest()
         elif path == 'templates':
             for root, dirs, files in os.walk(TEMPLATES_DIR_PATH):
                 for f in files:
                     index = len(TEMPLATES_DIR_PATH) + 1
                     filePath = os.path.join(root, f)[index:].replace('\\', '/')
-                    fileDict[filePath] = hashlib.md5(filePath).hexdigest()
+                    fileDict[filePath] = hashlib.md5(
+                        toBytes(filePath)).hexdigest()
         else:
             for root, dirs, files in os.walk(path):
                 for f in files:
@@ -463,13 +452,13 @@ class Command(BaseCommand):
                         "content", "{% page_attribute 'meta_description' %}")
                     createMetaDescription = False
                     
-        data = {
-            "title": titleContent,
-            "description": description,
-        }
+        data = collections.OrderedDict()
+        data["description"] = description
+        data["title"] = titleContent
+        
         cmsPageData = ("CMS_PAGE_DATA%sEND_CMS_PAGE_DATA" % 
                        json.dumps(data))
-        dataMd5 = hashlib.md5(cmsPageData).hexdigest()
+        dataMd5 = hashlib.md5(toBytes(cmsPageData)).hexdigest()
 
         # create ele
         pgAttr = etree.Comment(text=CMS_PAGE_ATTRS_COMMENT)
@@ -612,7 +601,7 @@ class Command(BaseCommand):
                 if name == 'data-vide-bg':
                     for path in fileDict:
                         if path.startswith(value):
-                            hashCode = hashlib.md5(value).hexdigest()
+                            hashCode = hashlib.md5(toBytes(value)).hexdigest()
                             extraDict[value] = hashCode
                             tag.set(name, hashCode)
         fileDict.update(extraDict)
@@ -624,11 +613,11 @@ class Command(BaseCommand):
                 if tag.text:
                     for key in CHANGE_WORD:
                         tag.text = tag.text.replace(
-                            key, hashlib.md5(key).hexdigest())
+                            key, hashlib.md5(toBytes(key)).hexdigest())
                 if tag.tail:
                     for key in CHANGE_WORD:
                         tag.tail = tag.tail.replace(
-                            key, hashlib.md5(key).hexdigest())
+                            key, hashlib.md5(toBytes(key)).hexdigest())
 
     #--------------------------------file---------------------------------------
     def findComment(self, filePath):
@@ -638,7 +627,7 @@ class Command(BaseCommand):
             commentList = re.findall(r"\<!--((.|\n)*?)--\>", content)
             
             for comment in commentList:
-                code = hashlib.md5(comment[0]).hexdigest()
+                code = hashlib.md5(toBytes(comment[0])).hexdigest()
                 content = content.replace(
                     "<!--" + comment[0] + "-->", "<!--" + code + "-->")
                 commentDict[code] = comment[0]
@@ -680,7 +669,7 @@ class Command(BaseCommand):
             content = f.read()
         for key in CHANGE_WORD:
             content = content.replace(
-                hashlib.md5(key).hexdigest(), CHANGE_WORD[key])
+                hashlib.md5(toBytes(key)).hexdigest(), CHANGE_WORD[key])
         with open(filePath, 'w') as f:
             f.write(content)
 
