@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 11011 2018-05-06 04:26:57Z Lavender $
+# $Id: pluginize.py 11376 2019-03-03 14:21:00Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-05-06 12:26:57 +0800 (週日, 06 五月 2018) $
-# $Revision: 11011 $
+# $Date: 2019-03-03 23:21:00 +0900 (週日, 03 三月 2019) $
+# $Revision: 11376 $
 
 import os
 import json
@@ -46,7 +46,8 @@ from html5lib.filters import sanitizer as filtersSanitizer
 from Zephyrus.boilerplate.management.commands import (
     TEMPLATES_DIR_PATH, STATIC_DIR_PATH, FIXTURES_DIR_PATH, ROOT_DIR_PATH)
 from Zephyrus.boilerplate.management.commands import (
-    createLogger, CSS_PROPERTIES)
+    createLogger, CSS_PROPERTIES, toBytes)
+from Zephyrus.boilerplate.management.commands import open3 as open
 
 logger = createLogger(__name__, "Pluginize.log")
 
@@ -192,7 +193,7 @@ class Placeholder2(Placeholder):
                         tagList.append(
                             Tag('a', placeholder.slot, 
                             hashlib.md5(
-                                placeholder.slot).hexdigest(), attrList))
+                                toBytes(placeholder.slot)).hexdigest(), attrList))
                     else:
                         img = root
                     
@@ -218,7 +219,8 @@ class Placeholder2(Placeholder):
                     
                     tagList.append(
                         Tag('img', placeholder.slot, 
-                        hashlib.md5(placeholder.slot).hexdigest(), attrList))
+                        hashlib.md5(
+                            toBytes(placeholder.slot)).hexdigest(), attrList))
                     
                     if cms.__version__.startswith('3.5'):
                         if root.tag == 'a':
