@@ -19,7 +19,7 @@ from django.conf.urls import url
 
 from . import views
 
-app_name = 'comment'
+#app_name = 'comment'
 
 urlpatterns = [
     url(r'^comment/add$', views.CommentView.as_view(), name='addComment'),
